@@ -12,6 +12,7 @@ $db = $gCms->GetDb();
 $config = $gCms->GetConfig();
 $tmp = $this->GetPreference('detail_returnid',-1);
 $hm =& $gCms->GetHierarchyManager();
+$page_meta = $gCms->variables['content_obj'];
 $curnode =& $hm->getNodeByAlias($gCms->variables['page_name']);
 $curcontent =& $curnode->GetContent();
 $modified_date = $curcontent->GetModifiedDate();
@@ -44,6 +45,13 @@ if ($this->GetPreference('content_var_title','') != '') {
 $pageSmarty = $this->GetPreference('page_smarty','');
 
 
+///// PAGE SPECIFIC METADATA /////
+
+if (is_object($page_meta) && $page_meta->Metadata() != '') {
+    $pageMeta = "\n" . $page_meta->Metadata();
+}
+
+
 
 ///// KEYWORDS /////
 
@@ -307,6 +315,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('description_block', $curcontent->GetPropertyValue($description_block));
    $this->smarty->assign('page_description', $desc);
    $this->smarty->assign('contentText', $countVars);
+   $this->smarty->assign('pageMeta', $pageMeta);
 }
 
 
