@@ -215,7 +215,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.6 4 July 2012. Additional optional meta tags added, Street, Postalcode, Country, Email, Telephone, Fax, Facebook page ID and Tweetme title. Minor bug fixes.</li>
 <li>Version 1.7.6.1 11 July 2012. Added IE7 Emulate option to X-UA-Compatible tag.</li>
 <li>Version 1.7.7 9 October 2012. Additional HTML block now accepts smarty.</li>
-<li>Version 1.7.8 6 November 2012. Fixed issue where canonical link for news articles showed default detail page URL rather than news story URL.</li></ul>';
+<li>Version 1.7.8 6 November 2012. Fixed issue where canonical link for news articles showed default detail page URL rather than news story URL.</li>
+<li>Version 1.7.9 26 November 2012. Added the ability to use CMSMS page specific metadata field instead of adding content block to your templates.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
@@ -224,7 +225,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <p>Firstly you need to remove the standard &#123;metadata} call, this is not compatible with Meta Max and may cause problems. You may also need to remove your <DOCTYPE>, opening <html> tag and <head> tags depending on which parameters you have enabled.</p>
 <p>Just add &#123;MetaMax} to the top or head of each template.</p>
 <p>If you are using the auto description option you will need to add &#123;capture}&#123;content block=\'Page Description\' oneline=\'true\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'page description content block\' input field, which in this example is Page Description.</p>
-<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks namie in the \'metadata content block\' input field, which in this example is Metadata.</p>
+<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'metadata content block\' input field, which in this example is Metadata.</p>
 <p>The Analytics search options are only required if you are using pretty URL\'s in conjunction with the search module\'s POST method otherwise simply adding the default cntnt01searchinput into your Analytics setup will track site search queries.</p>
 <p>There are more examples and instructions available at https://sites.google.com/site/metamaxwiki/ please feel free to contribute any examples and findings you have.</p>
 <h3>Support</h3>
